@@ -1,6 +1,6 @@
 package Reddit::Client;
 
-our $VERSION = '1.097';  
+our $VERSION = '1.0971';  
 # 1.097:
 # edit in main
 # edit on Comment and Link objects
@@ -727,7 +727,9 @@ sub set_listing_defaults {
 sub edit {
     	my ($self, $name, $text) = @_;
     	my $type = substr $name, 0, 2;
-    	croak '$fullname must be a post or comment' if $type ne 't1' && $type ne 't3';
+    	croak 'Argument 1 ($fullname) must be a post or comment.' if $type ne 't1' && $type ne 't3';
+	croak 'Argument 2 (text) is required. Empty strings are allowed.' unless defined $text;
+
 	my $data = {
 		thing_id	=> $name,
 		text		=> $text
